@@ -354,17 +354,17 @@ class ModelsTestCase(TransactionTestCase):
         assert_equal(tuple(qs.values_list('pk', flat=True)), (t.pk, t.pk))
         assert_equal(qs.fast_distinct().count(), 1)
 
-    def test_smart_queryset_fast_distinct_shuld_keep_ordering(self):
+    def test_smart_queryset_fast_distinct_should_keep_ordering(self):
         TestSmartModel.objects.create(name='a')
         TestSmartModel.objects.create(name='b')
         TestSmartModel.objects.create(name='c')
 
         assert_equal(
-            TestSmartModel.objects.order_by('name').fast_distinct().values_list('name', flat=True),
+            list(TestSmartModel.objects.order_by('name').fast_distinct().values_list('name', flat=True)),
             ['a', 'b', 'c']
         )
         assert_equal(
-            TestSmartModel.objects.order_by('-name').fast_distinct().values_list('name', flat=True),
+            list(TestSmartModel.objects.order_by('-name').fast_distinct().values_list('name', flat=True)),
             ['c', 'b', 'a']
         )
 
@@ -396,4 +396,3 @@ class ModelsTestCase(TransactionTestCase):
 
         obj = TestSmartModel.objects.create(name='1')
         assert_equal(obj, obj.get_locked_instance())
-
